/**
 * 
 */
package edu.westga.controller;

import java.util.*;

import twitter4j.Tweet;
import twitter4j.TwitterException;
import edu.westga.model.eventparser.*;
import edu.westga.model.tweetAggregator.*;

/**
 * @author Michael Obermeyer
 * 
 * This class handles the communication between the TweetAggregator
 * and the Event objects. This is intended to be used by the view
 * to retrieve the Event objects for display.
 *
 */
public class EventAggregator {

	private ArrayList<Event> officialEvents;
	private final TweetAggregator theAggregator;
	
	private static final String OFFICIAL_EVENTS = "UWGEvents";
	
	/**
	 * Creates an instance of EventAggregator.
	 * 
	 * @throws Exception if there is an issue connecting to Twitter 
	 */
	public EventAggregator() throws Exception{
		this.officialEvents = new ArrayList<Event>();
		
		try {
			this.theAggregator = new TweetAggregator();
		} catch (TwitterException e) {
			throw new Exception("An error has occurred when connecting to Twitter: " + e.getStatusCode());
		}
		
		this.refreshEvents();
	}

	/**
	 * Returns the list of events that have been retrieved from Twitter.
	 * These events only include events that UWGEvents follows.
	 * 
	 * @return @codeArrayList<Event>: The retrieved events.
	 */
	public ArrayList<Event> getOfficialEvents(){
		return this.officialEvents;
	}
	
	/**
	 * Updates the events from Twitter.
	 * 
	 * @throws Exception if there is an issue connecting to Twitter.
	 */
	public void refreshEvents() throws Exception{
		this.officialEvents = this.createEvents(OFFICIAL_EVENTS);
		//unofficial events would be created here.
	}
	
	//~~~~~~~~~~~~~~~~~~~~~~~~~~PRIVATE HELPER METHODS~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	
	//Recreates the list of events based on the query.
	//The query may or may not be needed as the TweetAggregator is developed.
	private ArrayList<Event> createEvents(String query) throws Exception {
		List<Tweet> tweets = new ArrayList<Tweet>();
		try {
			//This line of code needs to be replaced in the future with
			//a more direct way to pull UWGEvents.
			tweets = theAggregator.doSearch(query);
		} catch (TwitterException e) {
			throw new Exception("An error has occurred when connecting to Twitter: " + e.getStatusCode());
		}
		
		ArrayList<Event> events = new ArrayList<Event>();
		
		for(int i = 0; i < tweets.size(); i++){
			Tweet currentTweet = tweets.get(i);			
			Event currentEvent = Event.create(currentTweet);
			
			if(currentEvent != null){
				events.add(Event.create(currentTweet));
			}
		}
		
		return events;
	}
}
