package edu.westga.model.eventparser;

import com.mdimension.jchronic.*;
import com.mdimension.jchronic.utils.*;
import java.util.*;

public class DateParser {

	/**
	 * Accepts a string and attempts to find any dates within it. If
	 * no dates are found, null is returned.
	 * 
	 * Uses Today's date as a context date to parse relative dates such
	 * as, "Tomorrow," and "Next Tuesday."
	 * 
	 * Requires: text != null
	 * 
	 * 
	 * @param text: the text that contains a date
	 * @return the java.util.Date object representing the date found.
	 */
	public static Date parseDate(String text){
		return parseDate(text, new Date());
	}
	
	/**
	 * Accepts a string and attempts to find any dates within it. If
	 * no dates are found, null is returned.
	 * 
	 * The contextDate is used as a point of reference when terms like, "Tomorrow"
	 * or "Next Tuesday" are given. The contextDate currently does not have any
	 * effect on the outcome as it has not been implemented. Today's Date is used
	 * as the contextDate every time. This will hopefully be implemented in the future.
	 * 
	 * Requires: text != null
	 * 
	 * @param text: the text that contains a date
	 * @param contextDate: the Date that will be used as the context for parsing: not yet functional
	 * @return the java.util.Date object representing the date found.
	 */
	public static Date parseDate(String text, Date contextDate){
		if(text == null){
			throw new IllegalArgumentException("text cannot be null.");
		}
		
		Span theSpan = null;
		
		Options o = new Options();
		Calendar cal = Calendar.getInstance();
		cal.setTime(contextDate);
		o.setNow(cal);
		
		//Remove punctuation and unusual characters and create an array of words.
		String dateText = text.replaceAll("[,|?|.|;|!|']", "");
		dateText = dateText.replaceAll(" a ", " ");
		dateText = dateText.replaceAll(" day ", " ");
		dateText = dateText.toLowerCase();
		String[] words = dateText.split(" ");		
		
		Date parsedDate = parseContextDate(theSpan, o, words);
		
		if (parsedDate == null ) {
			for (int i = 0; i < words.length; i++) {
				if (words[i] == "next") {
					if (returnDayOfWeek(words) != "") {
						String dayOfWeek = returnDayOfWeek(words);
						
						//this is where we will add 7 days to the date.  Not sure how yet.
					
						//parsedDate = parseContextDate(theSpan, o, dayOfWeek);
					}
				}
			}
		}
		
		
		if (parsedDate == null) {
			parsedDate = parseDate(returnHolidayDateString(words));
		}
		return parsedDate;
	}

	/**
	 * @param theSpan
	 * @param o
	 * @param words
	 * @return
	 */
	private static Date parseContextDate(Span theSpan, Options o, String[] words) {
		for(int i = 0; i < words.length; i++){
			
			String subText = buildStringUpToCurrentWord(words, i);
			Span tempParse = Chronic.parse(subText);
			if(tempParse != null){
				theSpan = Chronic.parse(subText, o);	
			}	
		}		
		if(theSpan != null){
			return new Date(theSpan.getBeginCalendar().getTimeInMillis());
		}
		return null;
	}
	

	//Creates a string that consists of every word in words up to the ith word.
	//Puts a space between each word as well.
	private static String buildStringUpToCurrentWord(String[] words, int i) {
		String subText = "";
		for(int j = 0; j <= i; j++){
			subText += " " + words[j];
		}
		return subText;
	}
	
	private static String returnDayOfWeek(String[] words){
		String dayOfTheWeek = "";
		for (int i = 0; i < words.length; i ++) {
			if (words[i] == "monday" || words[i] == "tuesday" || words[i] == "wednesday" || 
			words[i] == "thursday" || words[i] == "friday" || words[i] == "saturday" || 
			words[i] == "sunday") {
				dayOfTheWeek = words[i];
			}
		}
		return dayOfTheWeek;
	}
	
	/**
	 * This helper method returns the date in string form depending on the if the array contains a holiday
	 * @param words the array of strings containing the tweet
	 * @return the date of the holiday in question, if it exists.
	 */
	private static String returnHolidayDateString(String[] words){
		String holidayDate = "";
		
		for (int i = 0; i < words.length; i++) {
			
			//sets the correct date if New Year's eve (as new years day already works)
			if (words[i] == "new" && words[i+1].contains("year")){
				
				if (words[i+2].contains("eve")){
					holidayDate = "December 31";
				}
			}
			
			//sets the correct date if MLK day or Martin Luther King day
			if (words[i] == "martin" && words[i+1] == "luther" && words[i+2] == "king" &&
			words[i+3] == "day" || words[i] == "mlk" && words[i+1] == "day"){
				holidayDate = "3rd monday in february";
			}
			
			//sets the correct date if Memorial Day
			if (words[i] == "memorial" ){
				//still needs to be done, as this currently won't parse "last (day of the week) in (month)",
				//since memorial day is the last monday in may
			}
			
			//sets the correct date if Flag Day
			if (words[i] == "flag" && words[i+1] == "day"){
				holidayDate = "june 14";
			}
			
		}
		
		return holidayDate;
		
	}
}
