package edu.westga.dateparser;

import static org.junit.Assert.*;

import java.util.Date;

import org.junit.Test;

import edu.westga.model.eventparser.DateParser;


public class dateParserTester {

	/**
	 * This set of tests covers Written dates to represent the dates 
	 * i.e. writing out the date by month, day, and year
	 * 
	 * Note: the second variable is not important for these tests.  This is where the post date will go.
	 * They are set as 0 for now to alleviate issues.
	 */
	@Test
	public void testWrittenDateNoTime() {
		assertEquals("Mon Jul 04 12:00:00 EDT 2011", DateParser.parseDate("July 4, 2011", new Date()).toString());	
	}
	
	@Test
	public void testWrittenDateWithTime() {
		assertEquals("Tue Aug 14 16:00:00 EDT 2012", DateParser.parseDate("August 14, 2012 4:00pm", new Date()).toString());
	}
	

	@Test
	public void testCompleteSentenceWithWrittenDateNoTime() {
		assertEquals("Mon Jul 04 12:00:00 EDT 2011", DateParser.parseDate("The killer WOW keg party starts on July 4 2011.  Don't forget" +
				"to bring a towel!!", new Date()).toString());
		
	}
	
	@Test
	public void testCompleteSentenceWithWrittenDateAndTime() {
		assertEquals("Thu Jul 23 19:15:00 EDT 2015", DateParser.parseDate("So I'm having a block party on July 23, 2015 at 7:15pm.  We're " +
				"gonna have cake and ice cream and ponies and Germans and Sausage and cake and Germans.", new Date()).toString());
	}
	
	
	/**
	 * This set of tests covers tests regarding dates with slashes representing the date
	 * 
	 * Note: the second variable is not important for these tests.  This is where the post date will go.
	 * They are set as 0 for now to alleviate issues.
	 */
	@Test
	public void testSlashDateNoTime() {
		assertEquals("Sat Jul 23 12:00:00 EDT 2011", DateParser.parseDate("7/23/11", new Date()).toString());
	}
	
	@Test
	public void testSlashDateWithTime() {
		assertEquals("Mon Dec 30 09:30:00 EST 2013", DateParser.parseDate("12/30/13 9:30am", new Date()).toString());
	}
	

	@Test
	public void testCompleteSentenceWithSlashDateNoTime() {
		assertEquals("Sun Sep 16 12:00:00 EDT 2012", DateParser.parseDate("I need someone to keep me company.  I'm lonely. 9/16/12 is my birthday.  Please " +
				"before I get all sad...", new Date()).toString());
	}
	
	@Test
	public void testCompleteSentenceWithSlashDateAndTime() {
		assertEquals("Mon Apr 15 16:30:00 EDT 2013", DateParser.parseDate("Who wants to stomp on the weasel?  It's national weasel stomping day on 4/15/13.  The stomping " +
				"begins at 4:30pm!  Don't miss the weasels!", new Date()).toString());
	}
	@Test
	public void testCompleteSentenceWithSlashDateAndTime2() {
		assertEquals("Fri Jun 24 17:00:00 EDT 2011", DateParser.parseDate("The university farming club is having its annual" +
				"plow day.  On 6/24/11, we'll be getting things started at 5:00pm.  See you there!", new Date()).toString());
	}
	
}
